@@ -13,6 +13,17 @@
 #' @importFrom stats dist
 #' @importFrom stats runif
 #' @importFrom stats sd
+#' 
+#' @name ptransform-deprecated
+#' @usage ptransform(data, vertices)
+#' @seealso \code{\link{psda-deprecated}}
+#' @keywords internal
+NULL
+
+#' @rdname psda-deprecated
+#' @section \code{ptransform}:
+#' For \code{ptransform}, use \code{\link{paggreg}}.
+#' 
 #' @export
 ptransform <- function(data, vertices){
   if(!is.data.frame(data)){
